# StandaloneRuleSpec

The rule specification. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**rule** | [**RuleConfig**](RuleConfig.md) |  | 
**org_id** | **str** | Unique identifier | 
**purpose** | **str** | Describes the purpose of the rule. Typically used by the system to aid in UI activities.  | [optional] 
**standalone_rule_policy_id** | **str, none_type** | A unique identifier which can be empty. The meaning of it being empty depends on the context in which it is used, but usually it implies that something is not set.  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


